<?php
/*
 * openbgpd_raw.php
 *
 * part of pfSense (https://www.pfsense.org)
 * Copyright (c) 2007-2015 Rubicon Communications, LLC (Netgate)
 * Copyright (c) 2009 Aarno Aukia (aarnoaukia@gmail.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
require("guiconfig.inc");
require("openbgpd.inc");

global $config;

if (isset($_POST['openbgpd_raw'])) {
	openbgpd_put_raw_config(base64_encode($_POST['openbgpd_raw']));
	write_config();
	openbgpd_install_conf();
}

$openbgpd_raw = openbgpd_get_raw_config();

$pgtitle = array(gettext("Package"), gettext("OpenBGPD"), gettext("Raw Config"));
include("head.inc");

$tab_array = array();
$tab_array[] = array(gettext("Settings"), false, "/pkg_edit.php?xml=openbgpd.xml&id=0");
$tab_array[] = array(gettext("Neighbors"), false, "/pkg.php?xml=openbgpd_neighbors.xml");
$tab_array[] = array(gettext("Groups"), false, "/pkg.php?xml=openbgpd_groups.xml");
$tab_array[] = array(gettext("Raw config"), true, "/openbgpd_raw.php");
$tab_array[] = array(gettext("Status"), false, "/openbgpd_status.php");
display_top_tabs($tab_array);

if ($savemsg) {
	print_info_box($savemsg);
}

$form = new Form();
$section = new Form_Section('OpenBGPD Configuration File');

$bgpconfig = new Form_Textarea(
	'openbgpd_raw',
	'Raw Configuration',
	$openbgpd_raw
);
$bgpconfig->setWidth(7);
$bgpconfig->setAttribute("rows", "30");
$bgpconfig->setAttribute("wrap", "off");
$bgpconfig->setHelp('The raw contents of the OpenBGPd configuration. View or edit the raw bgpd.conf as needed.');

$section->addInput($bgpconfig);

$form->add($section);

print($form);

?>
<div class="infoblock">
	<?=print_info_box(gettext('Once "Save" is clicked, the values entered in the "Settings", "Neighbors" and "Groups" tabs above will be overridden with this configuration.') . '<br/>' .
				gettext('To revert to the configuration generated by the GUI settings, save this form with empty input.') . '<br/>', 'info')?>
</div>
<?php include("foot.inc"); ?>
